import streamlit as st


def app():
    from streamlit_card_select.component import card_select
    st.subheader("Card Grid")

    # create a list of options
    options = [
        dict(option="one", image="https://picsum.photos/200/300"),
        dict(option="two", title="Card 2", description="This is card 2", image="https://picsum.photos/200/300"),
        dict(option="three", title="Card 3", image="https://picsum.photos/200/300"),
        dict(option="four", title="Card 4", description="This is card 4"),
    ]

    # Create an instance of our component with a constant `name` arg, and
    # print its output value.
    selected = card_select(options=options, default="four", imgHeight=200)
    st.write(f"Selected: {selected}")

    # slider data
    st.markdown('### Slider options:')
    st.json(options)


if __name__ == "__main__":
    app()



from streamlit_card_select.__version__ import __version__
from streamlit_card_select.component import card_select


if __name__ == '__main__':
    from streamlit_card_select.sample_app import app
    app()



import importlib
from setuptools import setup, find_packages


def readme():
    with open('README.md') as f:
        return f.read()


def version():
    loc = dict()
    with open('streamlit_card_select/__version__.py') as f:
        exec(f.read(), loc, loc)
    return loc.get('__version__')

def requirements():
    with open('requirements.txt') as f:
        return f.read().splitlines()

setup(
    name="streamlit-card-select",
    version=version(),
    author="Mirko Mälicke",
    author_email="mirko@hydrocode.de",
    description="Streamlit component to select a card from a grid",
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.6",
    install_requires=requirements(),
)
